Package: mitology
Type: Package
Title: Study of mitochondrial activity from RNA-seq data
Version: 1.5.0
Authors@R: c(person("Stefania", "Pirrotta", role = c("cre", "aut"),
                    email = "stefania.pirrotta@unipd.it",
                    comment = c(ORCID = "0009-0004-0030-217X")),
             person("Enrica", "Calura", role = c("aut", "fnd"), 
                    email = "enrica.calura@unipd.it",
                    comment = c(ORCID = "0000-0001-8463-2432")))
Description: mitology allows to study the mitochondrial activity throught
        high-throughput RNA-seq data. It is based on a collection of genes whose
        proteins localize in to the mitochondria. From these, mitology provides 
        a reorganization of the pathways related to mitochondria activity from 
        Reactome and Gene Ontology. Further a ready-to-use implementation of 
        MitoCarta3.0 pathways is included.
License: AGPL-3
biocViews: GeneExpression, RNASeq, Visualization, SingleCell, Spatial,
        Pathways, Reactome, GO
Imports: AnnotationDbi, ape, circlize, clusterProfiler, ComplexHeatmap,
        ggplot2, ggtree, magrittr, org.Hs.eg.db, ReactomePA, scales
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.5.0)
LazyData: false
Suggests: Biobase, BiocStyle, GSVA, methods, rmarkdown, knitr,
        SummarizedExperiment, testthat
VignetteBuilder: knitr
BugReports: https://github.com/CaluraLab/mitology/issues
URL: https://github.com/CaluraLab/mitology
git_url: https://git.bioconductor.org/packages/mitology
git_branch: devel
git_last_commit: 6b9bf15
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:52:25 UTC; biocbuild
Author: Stefania Pirrotta [cre, aut] (ORCID:
    <https://orcid.org/0009-0004-0030-217X>),
  Enrica Calura [aut, fnd] (ORCID:
    <https://orcid.org/0000-0001-8463-2432>)
Maintainer: Stefania Pirrotta <stefania.pirrotta@unipd.it>
