# Generated by roxygen2: do not edit by hand

export(enrichMito)
export(getGeneSets)
export(gseaMito)
export(mitoHeatmap)
export(mitoTreeHeatmap)
export(mitoTreePoint)
import(ggplot2)
importFrom(AnnotationDbi,mapIds)
importFrom(ComplexHeatmap,Heatmap)
importFrom(ComplexHeatmap,HeatmapAnnotation)
importFrom(ComplexHeatmap,rowAnnotation)
importFrom(ReactomePA,enrichPathway)
importFrom(ReactomePA,gsePathway)
importFrom(ape,Ntip)
importFrom(ape,extract.clade)
importFrom(circlize,colorRamp2)
importFrom(clusterProfiler,GSEA)
importFrom(clusterProfiler,enrichGO)
importFrom(clusterProfiler,enricher)
importFrom(clusterProfiler,gseGO)
importFrom(ggtree,geom_cladelab)
importFrom(ggtree,geom_tiplab)
importFrom(ggtree,geom_tippoint)
importFrom(ggtree,ggtree)
importFrom(ggtree,gheatmap)
importFrom(magrittr,"%>%")
importFrom(org.Hs.eg.db,org.Hs.eg.db)
importFrom(scales,rescale)
